@@ -22,13 +22,19 @@ drop_labels <- function(x, ..., drop.na = TRUE) {
 drop_labels_helper <- function(x, drop.na) {
   # get labels
   tidy.labels <- get_labels(x, attr.only = T, include.values = "n", include.non.labelled = F, drop.na = T)
+
   # return x, if no attribute
   if (is.null(tidy.labels)) return(x)
+
   # all missing in variable?
   if (all(is.na(x))) return(x)
+
   # remove labels with no values in data
   tidy.labels <- tidy.labels[get_values(x, drop.na = drop.na) %in% names(table(x))]
+
+  # check if tidy labels is empty - then remove everything
+  if (sjmisc::is_empty(tidy.labels)) tidy.labels <- ""
+
   # set labels
-  x <- set_labels(x, labels = tidy.labels, drop.na = drop.na)
-  return(x)
+  set_labels(x, labels = tidy.labels, drop.na = drop.na)
 }
