@@ -97,13 +97,16 @@
 #' @importFrom purrr map
 #' @export
 group_var <- function(x, ..., groupsize = 5, as.num = TRUE, right.interval = FALSE,
-                      groupcount = 30, suffix = "_gr") {
+                      groupcount = 30, append = FALSE, suffix = "_gr") {
   # evaluate arguments, generate data
   .dots <- match.call(expand.dots = FALSE)$`...`
   .dat <- get_dot_data(x, .dots)
 
   if (is.data.frame(x)) {
 
+    # remember original data, if user wants to bind columns
+    orix <- tibble::as_tibble(x)
+
     # iterate variables of data frame
     for (i in colnames(.dat)) {
       x[[i]] <- g_v_helper(
@@ -122,6 +125,9 @@ group_var <- function(x, ..., groupsize = 5, as.num = TRUE, right.interval = FAL
     if (!is.null(suffix) && !sjmisc::is_empty(suffix)) {
       colnames(x) <- sprintf("%s%s", colnames(x), suffix)
     }
+
+    # combine data
+    if (append) x <- dplyr::bind_cols(orix, x)
   } else {
     x <- g_v_helper(
       x = .dat,
@@ -139,15 +145,20 @@ group_var <- function(x, ..., groupsize = 5, as.num = TRUE, right.interval = FAL
 g_v_helper <- function(x, groupsize, as.num, right.interval, groupcount) {
   # do we have labels?
   varlab <- get_label(x)
+
   # group variable
   x <- group_helper(x, groupsize, right.interval, groupcount)
+
   # set new levels of grouped variable
   levels(x) <- seq_len(nlevels(x))
+
   # convert to numeric?
   if (as.num) x <- as.numeric(as.character(x))
+
   # set back variable labels
   if (!is.null(varlab)) x <- set_label(x, label = varlab)
-  return(x)
+
+  x
 }
 
 
@@ -215,7 +226,8 @@ g_l_helper <- function(x, groupsize, right.interval, groupcount) {
   }
   # set back variable labels
   if (!is.null(varlab)) retval <- set_label(retval, label = varlab)
-  return(retval)
+
+  retval
 }
 
 
@@ -239,7 +251,10 @@ group_helper <- function(x, groupsize, right.interval, groupcount) {
   }
   # Einteilung der Variablen in Gruppen. Dabei werden unbenutzte
   # Faktoren gleich entfernt
-  x <- droplevels(cut(x, breaks = c(seq(minval, max(x, na.rm = TRUE) + multip * groupsize, by = groupsize)),
-                      right = right.interval))
-  return(x)
+  x <-
+    droplevels(cut(x, breaks = c(
+      seq(minval, max(x, na.rm = TRUE) + multip * groupsize, by = groupsize)
+    ), right = right.interval))
+
+  x
 }
