@@ -6,7 +6,9 @@
 #' @seealso \code{\link{to_factor}} to convert numeric vectors into factors;
 #'            \code{\link{rec}} to recode variables.
 #'
-#' @param value Numeric, the new reference level.
+#' @param lvl Numeric, the new reference level.
+#' @param value Deprecated. Use \code{lvl} instead.
+#'
 #' @inheritParams to_factor
 #'
 #' @return \code{x} with new reference level. If \code{x}
@@ -19,7 +21,7 @@
 #'            numeric factors and b) changes the reference level by recoding
 #'            the factor's values using the \code{\link{rec}} function. Hence,
 #'            all values from lowest up to the reference level indicated by
-#'            \code{value} are recoded, with \code{value} starting as lowest
+#'            \code{lvl} are recoded, with \code{lvl} starting as lowest
 #'            factor value. See 'Examples'.
 #'
 #' @examples
@@ -28,7 +30,7 @@
 #' str(x)
 #' frq(x)
 #'
-#' x <- ref_lvl(x, value = 3)
+#' x <- ref_lvl(x, lvl = 3)
 #' str(x)
 #' frq(x)
 #'
@@ -37,11 +39,17 @@
 #'   select(c82cop1, c83cop2, c84cop3) %>%
 #'   to_factor()
 #'
-#' str(dat)
-#' ref_lvl(dat, c82cop1, c83cop2, value = 2) %>% str()
+#' frq(dat)
+#' ref_lvl(dat, c82cop1, c83cop2, lvl = 2) %>% frq()
 #'
 #' @export
-ref_lvl <- function(x, ..., value = NULL) {
+ref_lvl <- function(x, ..., lvl = NULL, value) {
+  # check deprecated arguments
+  if (!missing(value)) {
+    message("Argument `value` is deprecated. Please use `lvl` instead.")
+    lvl <- value
+  }
+
   # evaluate arguments, generate data
   .dots <- match.call(expand.dots = FALSE)$`...`
   .dat <- get_dot_data(x, .dots)
@@ -50,12 +58,12 @@ ref_lvl <- function(x, ..., value = NULL) {
 
     # iterate variables of data frame
     for (i in colnames(.dat)) {
-      x[[i]] <- ref_lvl_helper(.dat[[i]], value)
+      x[[i]] <- ref_lvl_helper(.dat[[i]], value = lvl)
     }
     # coerce to tibble
     x <- tibble::as_tibble(x)
   } else {
-    x <- ref_lvl_helper(.dat, value)
+    x <- ref_lvl_helper(.dat, value = lvl)
   }
 
   x
@@ -75,31 +83,41 @@ ref_lvl_helper <- function(x, value) {
     warning("`x` needs to be a factor with numeric factor levels.", call. = F)
     return(x)
   }
+
   # get values from factor
   vals <- as.numeric(levels(x))
+
   # check if ref-lvl exists in values
   if (!value %in% vals) {
     warning("`x` has no factor level indicated by the reference level `value`.", call. = F)
     return(x)
   }
+
   # get value labels
   val.labs <- get_labels(x)
+
   # get variable label
   var.lab <- get_label(x)
+
   # find position of reference level
   refpos <- which(vals == value)
+
   # new order of factor levels, if reference level
   # is on first position
   neword <- c(vals[refpos], vals[-refpos])
+
   # now recode variable. therefore, we need a string pattern
   # for the recoding
   rec.pattern <- paste0(sprintf("%i=%i;", neword, vals), collapse = "")
+
   # recode now
   x <- rec(x, rec = rec.pattern, as.num = FALSE)
+
   # set back labels
   if (!is.null(var.lab) && !sjmisc::is_empty(var.lab)) {
     set_label(x) <- var.lab
   }
+
   if (!is.null(val.labs)) {
     # we need "order" twice here, because "neword" refers to the actual
     # values of "x", so "neword" might have negative values, or zero.
@@ -108,5 +126,6 @@ ref_lvl_helper <- function(x, value) {
     # of these values.
     x <- set_labels(x, labels = val.labs[order(order(neword))])
   }
-  return(x)
+
+  x
 }
