@@ -161,7 +161,7 @@ set_labels <- function(x, ...,
   # special handling for data frames
   if (is.data.frame(x)) {
     # check if we have one label per variable
-    if (length(labels) == ncol(.dat)) {
+    if (is.list(labels) && length(labels) == ncol(.dat)) {
       # get column names
       cn <- colnames(.dat)
       # iterate all columns by number
@@ -370,7 +370,8 @@ set_labels_helper <- function(x, labels, force.labels, force.values, drop.na, va
     if (!drop.na && !is.null(current.na) && length(current.na) > 0)
       attr(x, attr.string) <- c(attr(x, attr.string, exact = T), current.na)
   }
-  return(x)
+
+  x
 }
 
 
