@@ -4,15 +4,15 @@
 #' @description This function converts a variable into a factor, but preserves
 #'                variable and value label attributes. See 'Examples'.
 #'
-#' @seealso \code{\link{to_value}} to convert a factor into a numeric value and
-#'            \code{\link{to_label}} to convert a value into a factor with labelled
+#' @seealso \code{\link{to_value}} to convert a factor into a numeric vector and
+#'            \code{\link{to_label}} to convert a vector into a factor with labelled
 #'            factor levels.
 #'
 #' @param x A vector or data frame.
-#' @param ... Optional, unquoted names of variables. Required, if \code{x} is
-#'          a data frame (and no vector) and only selected variables
-#'          from \code{x} should be processed. You may also use functions like
-#'          \code{:} or dplyr's \code{\link[dplyr]{select_helpers}}.
+#' @param ... Optional, unquoted names of variables that should be selected for
+#'          further processing. Required, if \code{x} is a data frame (and no
+#'          vector) and only selected variables from \code{x} should be processed.
+#'          You may also use functions like \code{:} or dplyr's \code{\link[dplyr]{select_helpers}}.
 #'          The latter must be stated as formula (i.e. beginning with \code{~}).
 #'          See 'Examples' or \href{../doc/design_philosophy.html}{package-vignette}.
 #' @param add.non.labelled Logical, if \code{TRUE}, non-labelled values also
@@ -23,10 +23,10 @@
 #'          will become the reference level. See \code{\link{ref_lvl}} for
 #'          details.
 #'
-#' @return A factor variable, including variable and value labels. If \code{x}
+#' @return A factor, including variable and value labels. If \code{x}
 #'           is a data frame, the complete data frame \code{x} will be returned,
 #'           where variables specified in \code{...} are coerced
-#'           to factor variables (including variable and value labels);
+#'           to factors (including variable and value labels);
 #'           if \code{...} is not specified, applies to all variables in the
 #'           data frame.
 #'
@@ -140,6 +140,7 @@ to_fac_helper <- function(x, add.non.labelled, ref.lvl) {
   # set back variable labels
   x <- set_label(x, label = varlab)
   # change reference level?
-  if (!is.null(ref.lvl)) x <- ref_lvl(x, value = ref.lvl)
-  return(x)
+  if (!is.null(ref.lvl)) x <- ref_lvl(x, lvl = ref.lvl)
+
+  x
 }
